summaryrefslogtreecommitdiff
path: root/log.c
diff options
context:
space:
mode:
authorUwe Hermann <uwe@hermann-uwe.de>2012-02-11 22:09:18 +0100
committerUwe Hermann <uwe@hermann-uwe.de>2012-02-11 22:42:40 +0100
commite09023b9dc8f1d6783a3bf6b05402a88060a795f (patch)
tree45dfece4b4139c22f1e2de7a2da5e3fabae3f162 /log.c
parentae53d0a5971121e03a07c469e39ff3cfa34a2111 (diff)
downloadlibsigrokdecode-e09023b9dc8f1d6783a3bf6b05402a88060a795f.tar.gz
libsigrokdecode-e09023b9dc8f1d6783a3bf6b05402a88060a795f.zip
Rename 'void *' callback parameters to 'user_data'.
This is better, both for consistency reasons, and also because 'data' is a bit too generic and might be confusing, especially since we have other 'data' fields in the code in various places.
Diffstat (limited to 'log.c')
-rw-r--r--log.c25
1 files changed, 14 insertions, 11 deletions
diff --git a/log.c b/log.c
index 97fde91..5693abf 100644
--- a/log.c
+++ b/log.c
@@ -27,7 +27,8 @@
static int srd_loglevel = SRD_LOG_WARN; /* Show errors+warnings per default. */
/* Function prototype. */
-static int srd_logv(void *data, int loglevel, const char *format, va_list args);
+static int srd_logv(void *user_data, int loglevel, const char *format,
+ va_list args);
/* Pointer to the currently selected log handler. Default: srd_logv(). */
static srd_log_handler_t srd_log_handler = srd_logv;
@@ -127,24 +128,25 @@ SRD_API char *srd_log_logdomain_get(void)
*
* @param handler Function pointer to the log handler function to use.
* Must not be NULL.
* @param data Pointer to private data to be passed on. This can be used by
* the caller to pass arbitrary data to the log functions. This
* pointer is only stored or passed on by libsigrokdecode, and
* is never used or interpreted in any way. The pointer is allowed
* to be NULL if the caller doesn't need/want to pass any data.
* @return SRD_OK upon success, SRD_ERR_ARG upon invalid arguments.
*/
-SRD_API int srd_log_handler_set(srd_log_handler_t handler, void *data)
+SRD_API int srd_log_handler_set(srd_log_handler_t handler, void *user_data)
{
if (!handler) {
srd_err("log: %s: handler was NULL", __func__);
return SRD_ERR_ARG;
}
/* Note: 'data' is allowed to be NULL. */
srd_log_handler = handler;
- srd_log_handler_data = data;
+ srd_log_handler_data = user_data;
return SRD_OK;
}
@@ -168,12 +170,13 @@ SRD_API int srd_log_handler_set_default(void)
return SRD_OK;
}
-static int srd_logv(void *data, int loglevel, const char *format, va_list args)
+static int srd_logv(void *user_data, int loglevel, const char *format,
+ va_list args)
{
int ret;
/* This specific log handler doesn't need the void pointer data. */
- (void)data;
+ (void)user_data;
/* Only output messages of at least the selected loglevel(s). */
if (loglevel > srd_loglevel)
@@ -127,24 +128,25 @@ SRD_API char *srd_log_logdomain_get(void)
* @param handler Function pointer to the log handler function to use.
* Must not be NULL.
- * @param data Pointer to private data to be passed on. This can be used by
- * the caller to pass arbitrary data to the log functions. This
- * pointer is only stored or passed on by libsigrokdecode, and
- * is never used or interpreted in any way. The pointer is allowed
- * to be NULL if the caller doesn't need/want to pass any data.
+ * @param user_data Pointer to private data to be passed on. This can be used
+ * by the caller to pass arbitrary data to the log functions.
+ * This pointer is only stored or passed on by libsigrokdecode,
+ * and is never used or interpreted in any way. The pointer
+ * is allowed to be NULL if the caller doesn't need/want to
+ * pass any data.
* @return SRD_OK upon success, SRD_ERR_ARG upon invalid arguments.
*/
@@ -127,24 +128,25 @@ SRD_API char *srd_log_logdomain_get(void)
return SRD_ERR_ARG;
}
- /* Note: 'data' is allowed to be NULL. */
+ /* Note: 'user_data' is allowed to be NULL. */
srd_log_handler = handler;